==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Depolama mevcut değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "Unable to set upload directory." : "Yükleme dizini ayarlanamadı.",
    "Invalid Token" : "Geçersiz Belirteç",
    "No file was uploaded. Unknown error" : "Dosya yüklenmedi. Bilinmeyen hata",
    "There is no error, the file uploaded with success" : "Dosya başarıyla yüklendi, hata oluşmadı",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "php.ini dosyasında upload_max_filesize ile belirtilen dosya yükleme sınırı aşıldı:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenecek dosyanın boyutu HTML formunda belirtilen MAX_FILE_SIZE limitini aşıyor",
    "The uploaded file was only partially uploaded" : "Dosya karşıya kısmen yüklenebildi",
    "No file was uploaded" : "Hiç dosya gönderilmedi",
    "Missing a temporary folder" : "Geçici bir dizin eksik",
    "Failed to write to disk" : "Diske yazılamadı",
    "Not enough storage available" : "Yeterli disk alanı yok",
    "The target folder has been moved or deleted." : "Hedef klasör taşındı veya silindi.",
    "Upload failed. Could not find uploaded file" : "Yükleme başarısız. Yüklenen dosya bulunamadı",
    "Upload failed. Could not get file info." : "Yükleme başarısız. Dosya bilgisi alınamadı.",
    "Invalid directory." : "Geçersiz dizin.",
    "Files" : "Dosyalar",
    "All files" : "Tüm dosyalar",
    "Favorites" : "Sık kullanılanlar",
    "Home" : "Ev",
    "Close" : "Kapat",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Total file size {size1} exceeds upload limit {size2}" : "Toplam dosya boyutu {size1}, {size2} gönderme sınırını aşıyor",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "Could not get result from server." : "Sunucudan sonuç alınamadı.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "Actions" : "Eylemler",
    "Download" : "İndir",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "Details" : "Ayrıntılar",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "This operation is forbidden" : "Bu işlem yasak",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu dizine yazılamıyor, lütfen günlüğü kontrol edin veya yönetici ile iletişime geçin",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef mevcut",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "{newName} already exists" : "{newName} zaten mevcut",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" adlandırılamadı, artık mevcut değil",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" ismi zaten \"{dir}\" klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten mevcut olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten mevcut olduğundan oluşturulamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken hata.",
    "No entries in this folder match '{filter}'" : "Bu klasörde hiçbir girdi '{filter}' ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} depolama alanı dolu, artık dosyalar güncellenmeyecek yada eşitlenmeyecek.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : " {owner} depolama alanı neredeyse dolu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "Folder" : "Klasör",
    "New folder" : "Yeni klasör",
    "{newname} already exists" : "{newname} zaten mevcut",
    "Upload" : "Yükle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenmeye çalışılırken bir hata oluştu",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya veya klasör <strong>değiştirildi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınızın</strong> oluşturulma ve değiştirilme hakkındaki bildirimlerini sınırla <em>(Sadece akışta)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya veya klasör <strong>silindi</strong>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya veya klasör <strong>geri alındı</strong>",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "%2$s created %1$s" : "%2$s, %1$s dosyasını oluşturdu",
    "%1$s was created in a public folder" : "%1$s herkese açık klasörde oluşturuldu",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "%2$s changed %1$s" : "%2$s, %1$s dosyasını değiştirdi",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "%2$s deleted %1$s" : "%2$s, %1$s dosyasını sildi",
    "You restored %1$s" : "%1$s ögesini geri aldınız",
    "%2$s restored %1$s" : "%2$s, %1$s ögesini geri aldı",
    "Changed by %2$s" : "%2$s tarafından değiştirildi",
    "Deleted by %2$s" : "%2$s tarafından silindi",
    "Restored by %2$s" : "%2$s tarafından geri yüklendi",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "File handling" : "Dosya işlemleri",
    "Maximum upload size" : "Azami yükleme boyutu",
    "max. possible: " : "mümkün olan en fazla: ",
    "Save" : "Kaydet",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM ile değişikliklerin uygulanması 5 dakika sürebilir.",
    "Missing permissions to edit from here." : "Buradan düzenleme için eksik yetki.",
    "Settings" : "Ayarlar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">Dosyalarınıza WebDAV aracılığıyla erişmek için</a> bu adresi kullanın",
    "Cancel upload" : "Yüklemeyi iptal et",
    "No files in here" : "Burada hiç dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt",
    "Changed by %2$s" : "%2$s tarafından değiştirildi",
    "Deleted by %2$s" : "%2$s tarafından silindi",
    "Restored by %2$s" : "%2$s tarafından geri yüklendi",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "You restored %1$s" : "%1$s ögesini geri aldınız"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Depolama mevcut değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "Unable to set upload directory." : "Yükleme dizini ayarlanamadı.",
    "Invalid Token" : "Geçersiz Belirteç",
    "No file was uploaded. Unknown error" : "Dosya yüklenmedi. Bilinmeyen hata",
    "There is no error, the file uploaded with success" : "Dosya başarıyla yüklendi, hata oluşmadı",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "php.ini dosyasında upload_max_filesize ile belirtilen dosya yükleme sınırı aşıldı:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenecek dosyanın boyutu HTML formunda belirtilen MAX_FILE_SIZE limitini aşıyor",
    "The uploaded file was only partially uploaded" : "Dosya karşıya kısmen yüklenebildi",
    "No file was uploaded" : "Hiç dosya gönderilmedi",
    "Missing a temporary folder" : "Geçici bir dizin eksik",
    "Failed to write to disk" : "Diske yazılamadı",
    "Not enough storage available" : "Yeterli disk alanı yok",
    "The target folder has been moved or deleted." : "Hedef klasör taşındı veya silindi.",
    "Upload failed. Could not find uploaded file" : "Yükleme başarısız. Yüklenen dosya bulunamadı",
    "Upload failed. Could not get file info." : "Yükleme başarısız. Dosya bilgisi alınamadı.",
    "Invalid directory." : "Geçersiz dizin.",
    "Files" : "Dosyalar",
    "All files" : "Tüm dosyalar",
    "File could not be found" : "Dosya bulunamadı",
    "Home" : "Ev",
    "Close" : "Kapat",
    "Favorites" : "Sık kullanılanlar",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Total file size {size1} exceeds upload limit {size2}" : "Toplam dosya boyutu {size1}, {size2} gönderme sınırını aşıyor",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "Error uploading file \"{fileName}\": {message}" : "\"{fileName}\" dosyası yüklenirken hata: {message}",
    "Could not get result from server." : "Sunucudan sonuç alınamadı.",
    "Uploading..." : "Yükleniyor...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "Actions" : "Eylemler",
    "Download" : "İndir",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "Details" : "Ayrıntılar",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "This operation is forbidden" : "Bu işlem yasak",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu dizine yazılamıyor, lütfen günlüğü kontrol edin veya yönetici ile iletişime geçin",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef mevcut",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "{newName} already exists" : "{newName} zaten mevcut",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" adlandırılamadı, artık mevcut değil",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" ismi zaten \"{dir}\" klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten mevcut olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten mevcut olduğundan oluşturulamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken hata.",
    "No entries in this folder match '{filter}'" : "Bu klasörde hiçbir girdi '{filter}' ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} depolama alanı dolu, artık dosyalar güncellenmeyecek yada eşitlenmeyecek.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : " {owner} depolama alanı neredeyse dolu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "Local link" : "Yerel bağlantı",
    "Folder" : "Klasör",
    "New folder" : "Yeni klasör",
    "{newname} already exists" : "{newname} zaten mevcut",
    "Upload" : "Yükle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenmeye çalışılırken bir hata oluştu",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya veya klasör <strong>değiştirildi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınızın</strong> oluşturulma ve değiştirilme hakkındaki bildirimlerini sınırla <em>(Sadece akışta)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya veya klasör <strong>silindi</strong>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya veya klasör <strong>geri alındı</strong>",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "%2$s created %1$s" : "%2$s, %1$s dosyasını oluşturdu",
    "%1$s was created in a public folder" : "%1$s herkese açık klasörde oluşturuldu",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "%2$s changed %1$s" : "%2$s, %1$s dosyasını değiştirdi",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "%2$s deleted %1$s" : "%2$s, %1$s dosyasını sildi",
    "You restored %1$s" : "%1$s ögesini geri aldınız",
    "%2$s restored %1$s" : "%2$s, %1$s ögesini geri aldı",
    "Changed by %2$s" : "%2$s tarafından değiştirildi",
    "Deleted by %2$s" : "%2$s tarafından silindi",
    "Restored by %2$s" : "%2$s tarafından geri yüklendi",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "File handling" : "Dosya işlemleri",
    "Maximum upload size" : "Azami yükleme boyutu",
    "max. possible: " : "mümkün olan en fazla: ",
    "Save" : "Kaydet",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM ile değişikliklerin uygulanması 5 dakika sürebilir.",
    "Missing permissions to edit from here." : "Buradan düzenleme için eksik yetki.",
    "Settings" : "Ayarlar",
    "Show hidden files" : "Gizli dosyaları göster",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV ile erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">bu adresi kullanın</a>",
    "No files in here" : "Burada hiç dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt"
},
"nplurals=2; plural=(n > 1);");
